@@ -366,7 +366,7 @@ class VariableClMigrateAdmin(UserHelper, Variable):
     def choice(self):
         return [
             ("none", ""),
-            ("all", _("Full access"))
+            ("all", _("Full access")),
             ("update", _("System update")),
         ]
 
